@@ -14,7 +14,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with PWSpy.  If not, see <https://www.gnu.org/licenses/>.
-
+import dataclasses
 import hashlib
 import os
 from datetime import datetime
@@ -24,7 +24,7 @@ import typing as t_
 from PyQt5.QtWidgets import QWidget
 from matplotlib import animation
 
-from pwspy.dataTypes import CameraCorrection, AcqDir, ICMetaData, ImCube
+from pwspy.dataTypes import CameraCorrection, Acquisition, PwsMetaData, PwsCube
 from pwspy_gui.ExtraReflectanceCreator.widgets.dialog import IndexInfoForm
 from pwspy.dataTypes import Roi
 from pwspy import dateTimeFormat
@@ -39,11 +39,17 @@ import logging
 from mpl_qt_viz.visualizers import PlotNd, DockablePlotWindow
 import pathlib as pl
 
+DirectoryDataFrame = t_.NewType("DirectoryDataFrame", pd.DataFrame)  # Type alias representing the data frame returned by `scanDirectory`
+# Has columns "setting", "cube", "material"
 
+
+@dataclasses.dataclass
 class Directory:
-    def __init__(self, df: pd.DataFrame, camCorr: CameraCorrection):
-        self.dataframe = df
-        self.cameraCorrection = camCorr
+    """
+    Groups together relevant data for a given "System Directory" in the ERCreator raw data collection.
+    """
+    dataframe: DirectoryDataFrame
+    cameraCorrection: CameraCorrection
 
 
 def scanDirectory(directory: str) -> Directory:
@@ -73,22 +79,28 @@ def scanDirectory(directory: str) -> Directory:
         filelist = pl.Path(file).parts  # Split file into components.
         s = filelist[-3]
         m = matMap[filelist[-2]]
-        file = AcqDir(file).pws.filePath  # old pws is saved directly in the "Cell{X}" folder. new pws is saved in "Cell{x}/PWS" the acqDir class helps us abstract that out and be compatible with both.
+        file = Acquisition(file).pws.filePath  # old pws is saved directly in the "Cell{X}" folder. new pws is saved in "Cell{x}/PWS" the Acquisition class helps us abstract that out and be compatible with both.
         rows.append({'setting': s, 'material': m, 'cube': file})
-    df = pd.DataFrame(rows)
-    return Directory(df, cam)
+    df: DirectoryDataFrame = pd.DataFrame(rows)
+    return Directory(dataframe=df, cameraCorrection=cam)
 
 
 class DataProvider:
-    def __init__(self, df: pd.DataFrame, camCorr: CameraCorrection):
-        self._df = df
-        self._cameraCorrection = camCorr
-        self._cubes = None
+    """
+    This object manages caching data and processing new data when it needs to be loaded.
 
-    def getCubes(self):
+    Args:
+        directory: The Directory object providing a reference to the actual data.
+    """
+    def __init__(self, directory: Directory):
+        self._df = directory.dataframe
+        self._cameraCorrection = directory.cameraCorrection
+        self._cubes: pd.DataFrame = None
+
+    def getCubes(self) -> t_.Optional[pd.DataFrame]:
         return self._cubes
 
-    def getDataFrame(self):
+    def getDataFrame(self) -> pd.DataFrame:
         return self._df
 
     def loadCubes(self, includeSettings: t_.List[str], binning: int, parallelProcessing: bool):
@@ -96,7 +108,7 @@ class DataProvider:
         if binning is None:
             args = {'correction': None, 'binning': None}
             for cube in df['cube']:
-                md = ICMetaData.loadAny(cube)
+                md = PwsMetaData.loadAny(cube)
                 if md.binning is None:
                     raise Exception("No binning metadata found. Please specify a binning setting.")
                 elif md.cameraCorrection is None:
@@ -105,17 +117,18 @@ class DataProvider:
         else:
             args = {'correction': self._cameraCorrection, 'binning': binning}
         self._cubes = loadAndProcess(df, self._processIm, parallel=parallelProcessing, procArgs=[args])
+        self._cubes['material'] = self._cubes['material'].astype('category')
 
-    def _processIm(self, im: ImCube, kwargs) -> ImCube:
+    def _processIm(self, im: PwsCube, kwargs) -> PwsCube:
         """
         This processor function may be run in parallel to pre-process each raw image.
 
         Args:
-            im: The `ImCube` to be preprocessed.
-            kwargs: These keyword arguments are passed to `ImCube.correctCameraEffects`
+            im: The `PwsCube` to be preprocessed.
+            kwargs: These keyword arguments are passed to `PwsCube.correctCameraEffects`
 
         Returns:
-            The same ImCube that was provided as input.
+            The same PwsCube that was provided as input.
         """
         im.correctCameraEffects(**kwargs)
         im.normalizeByExposure()
@@ -170,7 +183,7 @@ class ERWorkFlow:
     def loadCubes(self, includeSettings: t_.List[str], binning: int, parallelProcessing: bool):
         self.dataprovider.loadCubes(includeSettings, binning, parallelProcessing)
 
-    def plot(self, includeSettings: t_.List[str], binning: int, parallelProcessing: bool, numericalAperture: float, saveToPdf: bool = False, saveDir: str = None):
+    def plot(self, includeSettings: t_.List[str], binning: int, parallelProcessing: bool, numericalAperture: float):
         self.loadIfNeeded(includeSettings, binning, parallelProcessing)
         cubes = self.dataprovider.getCubes()
         materials = set(cubes['material'])
@@ -179,15 +192,9 @@ class ERWorkFlow:
         matCombos = er.generateMaterialCombos(materials)
 
         print("Select an ROI")
-        verts = cubes['cube'].sample(n=1).iloc[0].selectLassoROI()  # Select an ROI to analyze
-        mask = Roi.fromVerts(verts, cubes['cube'].sample(n=1).iloc[0].data.shape[:-1])
-        self.figs.extend(er.plotExtraReflection(cubes, theoryR, matCombos, numericalAperture, mask, plotReflectionImages=True))  # TODO rather than opening a million new figures open a single window that lets you flip through them.
-        if saveToPdf:
-            with PdfPages(os.path.join(saveDir, f"fig_{datetime.strftime(datetime.now(), '%d-%m-%Y %HH%MM%SS')}.pdf")) as pp:
-                for i in plt.get_fignums():
-                    f = plt.figure(i)
-                    f.set_size_inches(9, 9)
-                    pp.savefig(f)
+        roi = cubes['cube'].sample(n=1).iloc[0].selectLassoROI()  # Select an ROI to analyze
+        cubeDict = cubes.groupby('setting').apply(lambda df: df.groupby('material')['cube'].apply(list).to_dict()).to_dict()  # Transform data frame to a dict of dicts of lists for input to `plot`
+        self.figs.extend(er.plotExtraReflection(cubeDict, theoryR, matCombos, roi))
 
     def save(self, includeSettings: t_.List[str], binning: int, parallelProcessing: bool, numericalAperture: float, parentWidget: QWidget):
         self.loadIfNeeded(includeSettings, binning, parallelProcessing)
@@ -199,15 +206,25 @@ class ERWorkFlow:
             theoryR = er.getTheoreticalReflectances(materials,
                                                     sCubes['cube'].iloc[0].wavelengths, numericalAperture)  # Theoretical reflectances
             matCombos = er.generateMaterialCombos(materials)
-            combos = er.getAllCubeCombos(matCombos, sCubes)
+            matCubes = sCubes.groupby('material')['cube'].apply(list).to_dict()
+            combos = er.getAllCubeCombos(matCombos, matCubes)
             erCube, rExtraDict = er.generateRExtraCubes(combos, theoryR, numericalAperture)
             dock = DockablePlotWindow(title=setting)
-            for k in rExtraDict.keys():
+            dock.addWidget(
+                PlotNd(erCube.data,
+                       title='Mean',
+                       indices=[range(erCube.data.shape[0]), range(erCube.data.shape[1]),
+                                erCube.wavelengths],
+                       names=('y', 'x', 'lambda')),
+                title='Mean'
+            )
+            for matCombo, rExtraArr in rExtraDict.items():
                 dock.addWidget(
-                    PlotNd(rExtraDict[k][0], title=k,
+                    PlotNd(rExtraArr, title=matCombo,
                            indices=[range(erCube.data.shape[0]), range(erCube.data.shape[1]),
-                                    erCube.wavelengths]),
-                    title=str(k)
+                                    erCube.wavelengths],
+                           names=('y', 'x', 'lambda')),
+                    title=str(matCombo)
                 )
             logger = logging.getLogger(__name__)
             logger.info(f"Final data max is {erCube.data.max()}")
@@ -248,8 +265,7 @@ class ERWorkFlow:
         anis = []
         figs = []  # These lists just maintain references to matplotlib figures to keep them responsive.
         cubes = self.dataprovider.getCubes()
-        verts = cubes['cube'].sample(n=1).iloc[0].selectLassoROI()  # Select a random of the selected cubes and use it to prompt the user for an analysis ROI
-        mask = Roi.fromVerts(verts=verts, dataShape=cubes['cube'].sample(n=1).iloc[0].data.shape[:-1])
+        roi = cubes['cube'].sample(n=1).iloc[0].selectLassoROI()  # Select a random of the selected cubes and use it to prompt the user for an analysis ROI
         for mat in set(cubes['material']):
             c = cubes[cubes['material'] == mat]
             fig, ax = plt.subplots()
@@ -262,7 +278,7 @@ class ERWorkFlow:
             anims = []
             for i, row in c.iterrows():
                 im = row['cube']
-                spectra = im.getMeanSpectra(mask)[0]
+                spectra = im.getMeanSpectra(roi)[0]
                 ax.plot(im.wavelengths, spectra, label=row['setting'])
                 anims.append((ax2.imshow(im.data.mean(axis=2), animated=True,
                                          clim=[np.percentile(im.data, .5), np.percentile(im.data, 99.5)]),
@@ -283,5 +299,5 @@ class ERWorkFlow:
         """
         self.currDir = directory
         directory = self.fileStruct[directory]
-        self.dataprovider = DataProvider(directory.dataframe, directory.cameraCorrection)
+        self.dataprovider = DataProvider(directory)
         return set(self.dataprovider.getDataFrame()['setting'])
