@@ -2,7 +2,7 @@ import typing as t_
 
 import numpy as np
 from PyQt5.QtCore import QObject
-from pwspy.utility.acquisition import SequencerStep, SeqAcqDir, PositionsStep, TimeStep, SequencerCoordinate, IterableSequencerStep
+from pwspy.utility.acquisition import SequencerStep, SequenceAcquisition, PositionsStep, TimeStep, SequencerCoordinate, IterableSequencerStep
 import pwspy.dataTypes as pwsdt
 from pwspy_gui.PWSAnalysisApp._roiManager import ROIManager
 
@@ -14,9 +14,9 @@ class Options(t_.NamedTuple):
 
 class SequenceController:
     """A utility class to help with selected acquisitions from a sequence that includes a multiple position and time series. both are optional"""
-    def __init__(self, sequence: SequencerStep, acqs: t_.Sequence[SeqAcqDir]):
+    def __init__(self, sequence: SequencerStep, acqs: t_.Sequence[SequenceAcquisition]):
         self.sequence = sequence
-        self.coordMap: t_.Dict[pwsdt.AcqDir, SequencerCoordinate] = {acq.acquisition: acq.sequencerCoordinate for acq in acqs}  # A dictionary of the sequence coords keyed by tha acquisition
+        self.coordMap: t_.Dict[pwsdt.Acquisition, SequencerCoordinate] = {acq.acquisition: acq.sequencerCoordinate for acq in acqs}  # A dictionary of the sequence coords keyed by tha acquisition
 
         self.iterSteps: t_.Tuple[IterableSequencerStep] = tuple((step for step in sequence.iterateChildren() if isinstance(step, IterableSequencerStep)))
         self._indices = tuple(0 for step in self.iterSteps)
@@ -24,20 +24,20 @@ class SequenceController:
     def getIterationNames(self, idx: int) -> t_.Sequence[str]:
         return tuple((self.iterSteps[idx].getIterationName(i) for i in range(self.iterSteps[idx].stepIterations())))
 
-    def setCoordinates(self, *idxs: t_.Sequence[int]) -> pwsdt.AcqDir:
+    def setCoordinates(self, *idxs: t_.Sequence[int]) -> pwsdt.Acquisition:
         acq = self.getAcquisitionForIndices(*idxs)
         self._indices = idxs
         return acq
 
-    def getIndicesForAcquisition(self, acq: t_.Union[SeqAcqDir, pwsdt.AcqDir]) -> t_.Tuple[int, ...]:
+    def getIndicesForAcquisition(self, acq: t_.Union[SequenceAcquisition, pwsdt.Acquisition]) -> t_.Tuple[int, ...]:
         """Returns the iteration indices of the given acquisition in the form (timeIdx, posIdx)"""
-        coord: SequencerCoordinate = acq.sequencerCoordinate if isinstance(acq, SeqAcqDir) else self.coordMap[acq]
+        coord: SequencerCoordinate = acq.sequencerCoordinate if isinstance(acq, SequenceAcquisition) else self.coordMap[acq]
         idxs = []
         for step in self.iterSteps:
             idxs.append(coord.getStepIteration(step))
         return tuple(idxs)
 
-    def getAcquisitionForIndices(self, *idxs: int) -> pwsdt.AcqDir:
+    def getAcquisitionForIndices(self, *idxs: int) -> pwsdt.Acquisition:
         step: SequencerStep = self.iterSteps[np.argmax([len(i.getTreePath()) if i is not None else 0 for i in self.iterSteps])]  # The step that is furthest down the tree path
         coordRange = step.getCoordinate()
         for idx, step in zip(idxs, self.iterSteps):
@@ -67,7 +67,7 @@ class RoiController(QObject):
     def getOptions(self, axis: int) -> Options:
         return self._options[axis]
 
-    def setRoiChanged(self, acq: pwsdt.AcqDir, roiFile: pwsdt.RoiFile, overwrite: bool):
+    def setRoiChanged(self, acq: pwsdt.Acquisition, roiFile: pwsdt.RoiFile, overwrite: bool):
         idxs = self._seqController.getIndicesForAcquisition(acq)
         for i, (step, option, idx) in enumerate(zip(self._seqController.iterSteps, self._options, idxs)):
             if not option.copyAlong:
@@ -77,7 +77,7 @@ class RoiController(QObject):
                 acq = self._seqController.getAcquisitionForIndices(*newIdxs)
                 self._roiManager.createRoi(acq, roiFile.getRoi(), roiFile.name, roiFile.number, overwrite=overwrite)
 
-    def deleteRoi(self, acq: pwsdt.AcqDir, roiFile: pwsdt.RoiFile):
+    def deleteRoi(self, acq: pwsdt.Acquisition, roiFile: pwsdt.RoiFile):
         idxs = self._seqController.getIndicesForAcquisition(acq)
 
         for i, (step, option, idx) in enumerate(zip(self._seqController.iterSteps, self._options, idxs)):
